@@ -13,7 +13,6 @@
 
 #include <QUrl>
 
-
 class KJob;
 namespace KIO
 {
@@ -22,7 +21,6 @@ class Job;
 
 namespace KParts
 {
-
 class ReadOnlyPartPrivate;
 class BrowserExtension;
 class OpenUrlArguments;
@@ -101,7 +99,7 @@ public Q_SLOTS:
      *
      * If you reimplement it, don't forget to set the caption, usually with
      * @code
-     * emit setWindowCaption( url.toDisplayString() );
+     * Q_EMIT setWindowCaption( url.toDisplayString() );
      * @endcode
      * and also, if the URL refers to a local file, resolve it to a
      * local path and call setLocalFilePath().
@@ -226,8 +224,9 @@ Q_SIGNALS:
      * Hosting applications will want to know when the process of loading the data
      * is finished, so that they can access the data when everything is loaded.
      **/
-    void completed();
+    void completed(); // clazy:exclude=overloaded-signal
 
+#if KPARTS_ENABLE_DEPRECATED_SINCE(5, 80)
     /**
      * Same as the above signal except it indicates whether there is
      * a pending action to be executed on a delay timer. An example of
@@ -236,8 +235,25 @@ Q_SIGNALS:
      * to give the user the ability to cancel such pending actions.
      *
      * @p pendingAction true if a pending action exists, false otherwise.
+     *
+     * @deprecated since 5.80, use the KParts::ReadOnlyPart::completedWithPendingAction() signal
      */
-    void completed(bool pendingAction);
+    KPARTS_DEPRECATED_VERSION(5, 81, "Use the KParts::ReadOnlyPart::completedWithPendingAction() signal")
+    void completed(bool pendingAction); // clazy:exclude=overloaded-signal
+#endif
+
+    /**
+     * This signal is similar to the @c KParts::ReadOnlyPart::completed() signal
+     * except it is only emitted if there is still a pending action to be executed
+     * on a delayed timer.
+     *
+     * An example of this is the meta-refresh tags on web pages used to reload/redirect
+     * after a certain period of time. This signal is useful if you want to give the
+     * user the ability to cancel such pending actions.
+     *
+     * @since 5.81
+     */
+    void completedWithPendingAction();
 
     /**
      * Emit this if loading is canceled by the user or by an error.
@@ -317,9 +333,6 @@ protected:
     ReadOnlyPart(ReadOnlyPartPrivate &dd, QObject *parent);
 
 private:
-    Q_PRIVATE_SLOT(d_func(), void _k_slotJobFinished(KJob *job))
-    Q_PRIVATE_SLOT(d_func(), void _k_slotStatJobFinished(KJob *))
-
     Q_DISABLE_COPY(ReadOnlyPart)
 };
 
